sanity_check: Run check with sanitizers

Description Usage Arguments Details Value Note See Also

Description

Runs R CMD check with address checking

Usage

1
sanity_check(pkg = ".")

Arguments

pkg

the path to the package to be tested

Details

The package will download and build a docker image containing a specially built R binary that has address sanitizing enabled. It will also check for undefined behavior. The results of the check should appear in the parent directory of the package directory. You must install docker and start the daemon for this package to work.

Value

The Rcheck directory will be written to the parent of the package directory. If the package uses testthat, the testing results will be printed to the console.

Note

This can take a very long time to run, so you may wish to run it in a separate R session.

See Also

https://hub.docker.com/r/rocker/r-devel-san/


thk686/sanitycheckr documentation built on May 12, 2019, 7:21 p.m.