Description Usage Arguments Details Value Note See Also
Runs R CMD check with address checking
1 | sanity_check(pkg = ".")
|
pkg |
the path to the package to be tested |
The package will download and build a docker image containing a specially built R binary that has address sanitizing enabled. It will also check for undefined behavior. The results of the check should appear in the parent directory of the package directory. You must install docker and start the daemon for this package to work.
The Rcheck directory will be written to the parent of the package
directory. If the package uses testthat, the testing results
will be printed to the console.
This can take a very long time to run, so you may wish to run it in a separate R session.
https://hub.docker.com/r/rocker/r-devel-san/
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.